function PlotParameter(grp,EQ,DATA,xname,yname,fit,addsig,deq)
%PlotParameter(grp,DATA,xname,yname,fit) Plots parameter data
%   Kevin Mackie, 2001/07/16
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: grp (Ax2) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM)
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%          fit 1 linear 2 bilinear
%          addsig 1 mean only 2 mean+1 sigma
%		   deq 1 export the design equations, 2 don't
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots the IM DM relationship showing sensitivity of the relationship
% to design parameters.  Parameters can be varied up to 16 values.

[m,n]=size(grp);

[xylog,linexlog,lineylog,Fits,Dispersion,ssig]=FitData(grp,fit,EQ);

ass=[];
for k=1:n,
   ass=[ass grp{k}.v(:,1)];
end;
%save ass.txt ass -ascii

% output to command line
Fits
Dispersion

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

clrs='brmgcykbrmgcy';
lins='ox+^*sdv<>ph.';
wids=0.5:0.5:0.5*(n-1)+0.5;

logplot='H=loglog(';
legplot='legend(';
for k=1:n,
   logplot=sprintf('%sxylog{%i}.v(:,1),xylog{%i}.v(:,2),''%c%c'', ', ...
      		logplot,k,k,clrs(k),lins(k));
end
for k=1:n,
   logplot=sprintf('%slinexlog{%i},lineylog{%i},''%c-''',logplot,k,k,clrs(k));
   legplot=sprintf('%sstrcat(DATA.name,''='',num2str(DATA.vals(%i)))',legplot,k);
   if k<n,
      logplot=sprintf('%s, ',logplot);
	  legplot=sprintf('%s, ',legplot);
   end;
end

if addsig == 2,
   for k=1:n,
      logplot=sprintf('%s,linexlog{%i},ssig{%i}.p,''%c-.'',linexlog{%i},ssig{%i}.m,''%c-.''', ...
   			logplot,k,k,clrs(k),k,k,clrs(k));
   end
end;

logplot=sprintf('%s);',logplot);
legplot=sprintf('%s,4);',legplot);

eval(logplot);
axis tight;
set(H,'MarkerSize',4);
addl=get(HH,'Children');
cntr=1;
for k=1:length(addl),
   if strcmp(get(addl(k),'Type'),'line')
      if and(~strcmp(get(addl(k),'LineStyle'),'none'), ...
	  	    ~strcmp(get(addl(k),'LineStyle'),'-.'));
	     set(addl(k),'LineWidth',wids(cntr));
		 cntr=cntr+1;
	  end;
   end;
end;
grid on;
xlabel(xname);
ylabel(yname);
title('Intensity Measure vs Demand Measure (Parameters)');
eval(legplot);
set(HH,'Tag','Axes1');

vax=axis;

% add sigma info to plot
siginf='\sigma=';
for k=1:n,
   siginf=sprintf('%s%1.2f',siginf,Dispersion(k));
   if k<n,
      siginf=sprintf('%s, ',siginf);
   end;
end;
tboxx=vax(1)+(vax(2)-vax(1))/500;
tboxy=vax(4)-(vax(4)-vax(3))/500;
TT=text(tboxx,tboxy,siginf);
set(TT,'Tag','sigma');
set(TT,'FontSize',9);
set(TT,'VerticalAlignment','top');

if deq==1,
   % add design equation information
   [r,c]=size(Fits);
   for k=1:n,
      for j=1:c/2,
         Av(k,j)=Fits(k,(j-1)*2+2);
	     Bv(k,j)=Fits(k,(j-1)*2+1);
	     Pv(k,j)=DATA.vals(k);
      end;
   end;
   
   figure;
   subplot(2,1,1),
   plot(Pv,Av,'-.x');
   title('A coefficient');
   subplot(2,1,2),
   plot(Pv,Bv,'-.o');
   title('B coefficient');
   for j=1:c/2,
      % polynomial least squares fit using Matlab routines
      N=2;
      % P fits are in form B (slope), A (intercept)
      Af{j}.v=polyfit(Pv(:,j),Av(:,j),N);
      Bf{j}.v=polyfit(Pv(:,j),Bv(:,j),N);
	  
      liney{j}=[Pv(1,j):(Pv(n,j)-Pv(1,j))/10:Pv(n,j)]';
      lineA{j}=zeros(length(liney{j}),1);
      lineB{j}=zeros(length(liney{j}),1);

      eqnA{j}=sprintf('A{%i}=',j);
      eqnB{j}=sprintf('B{%i}=',j);
      for i=0:N,
         lineA{j}=lineA{j}+Af{j}.v(i+1)*liney{j}.^(N-i);
	     lineB{j}=lineB{j}+Bf{j}.v(i+1)*liney{j}.^(N-i);
		 if Af{j}.v(i+1) < 0,
   	        eqnA{j}=sprintf('%s%.3f*x^%i',eqnA{j},Af{j}.v(i+1),N-i);
	     else
		    eqnA{j}=sprintf('%s+%.3f*x^%i',eqnA{j},Af{j}.v(i+1),N-i);
	     end;
		 if Bf{j}.v(i+1) < 0,
   	        eqnB{j}=sprintf('%s%.3f*x^%i',eqnB{j},Bf{j}.v(i+1),N-i);
		 else
		    eqnB{j}=sprintf('%s+%.3f*x^%i',eqnB{j},Bf{j}.v(i+1),N-i);
		 end;
   	    % strcat(eqnB,lineB{j});
      end;
      eqnA{j}
      eqnB{j}
      eqnA{j}=sprintf('%s;',eqnA{j});
      eqnB{j}=sprintf('%s;',eqnB{j});
   
      subplot(2,1,1),
      hold on;
	  plot(liney{j},lineA{j},'--p');
	  subplot(2,1,2),
	  hold on;
	  plot(liney{j},lineB{j},'--p');
   end;

   % enter parameter value
   prompt='Enter parameter value:';
   titl='Design Parameter';
   def={''};
   answer=inputdlg(prompt,titl,1,def);
   prtv=sprintf('x=%s;',answer{1});
   eval(prtv);
   for j=1:c/2,
      eval(eqnA{j});
      eval(eqnB{j});
	  if B{j} < 0,
         Design_Equation{j}=sprintf('log(EDP)=%.3f%.3f*log(IM)',A{j},B{j});
	  else
	     Design_Equation{j}=sprintf('log(EDP)=%.3f+%.3f*log(IM)',A{j},B{j});
	  end;
   end;
   celldisp(Design_Equation);
end;
